BOOST_LIB library macros

### `BOOST_LIB` library macros

##### `BOOST_LIB_C_GNU`

GNU glibc Standard C library. Version number available as major, and minor.

Symbol | Version
--- | ---
`__GLIBC__` | detection
`__GNU_LIBRARY__` | detection
`__GLIBC__`, `__GLIBC_MINOR__` | V.R.0
`__GNU_LIBRARY__`, `__GNU_LIBRARY_MINOR__` | V.R.0

##### `BOOST_LIB_C_UC`

uClibc Standard C library.

Symbol | Version
--- | ---
`__UCLIBC__` | detection
`__UCLIBC_MAJOR__`, `__UCLIBC_MINOR__`, `__UCLIBC_SUBLEVEL__` | V.R.P

##### `BOOST_LIB_C_VMS`

VMS libc Standard C library. Version number available as major, minor, and patch.

Symbol | Version
--- | ---
`__CRTL_VER` | detection
`__CRTL_VER` | V.R.P

##### `BOOST_LIB_C_ZOS`

z/OS libc Standard C library. Version number available as major, minor, and patch.

Symbol | Version
--- | ---
`__LIBREL__` | detection
`__LIBREL__` | V.R.P
`__TARGET_LIB__` | V.R.P

##### `BOOST_LIB_STD_CXX`

libc++ C++ Standard Library.

Symbol | Version
--- | ---
`_LIBCPP_VERSION` | detection
`_LIBCPP_VERSION` | V.0.P

##### `BOOST_LIB_STD_DINKUMWARE`

Dinkumware Standard C++ Library. If available version number as major, minor, and patch.

Symbol | Version
--- | ---
`_YVALS`, `__IBMCPP__` | detection
`_CPPLIB_VER` | detection
`_CPPLIB_VER` | V.R.0

##### `BOOST_LIB_STD_COMO`

Comeau Computing Standard C++ Library. Version number available as major.

Symbol | Version
--- | ---
`__LIBCOMO__` | detection
`__LIBCOMO_VERSION__` | V.0.0

##### `BOOST_LIB_STD_MSIPL`

Modena Software Lib++ Standard C++ Library.

Symbol | Version
--- | ---
`MSIPL_COMPILE_H` | detection
`__MSIPL_COMPILE_H` | detection

##### `BOOST_LIB_STD_MSL`

Metrowerks Standard C++ Library. Version number available as major, minor, and patch.

Symbol | Version
--- | ---
`__MSL_CPP__` | detection
`__MSL__` | detection
`__MSL_CPP__` | V.R.P
`__MSL__` | V.R.P

##### `BOOST_LIB_STD_RW`

Roguewave Standard C++ library. If available version number as major, minor, and patch.

Symbol | Version
--- | ---
`__STD_RWCOMPILER_H__` | detection
`_RWSTD_VER` | detection
`_RWSTD_VER` | V.R.P

##### `BOOST_LIB_STD_SGI`

SGI Standard C++ library. If available version number as major, minor, and patch.

Symbol | Version
--- | ---
`__STL_CONFIG_H` | detection
`__SGI_STL` | V.R.P

##### `BOOST_LIB_STD_GNU`

GNU libstdc++ Standard C++ library. Version number available as year (from 1970), month, and day.

Symbol | Version
--- | ---
`__GLIBCXX__` | detection
`__GLIBCPP__` | detection
`__GLIBCXX__` | V.R.P
`__GLIBCPP__` | V.R.P

##### `BOOST_LIB_STD_STLPORT`

STLport Standard C++ library. Version number available as major, minor, and patch.

Symbol | Version
--- | ---
`__SGI_STL_PORT` | detection
`_STLPORT_VERSION` | detection
`_STLPORT_MAJOR`, `_STLPORT_MINOR`, `_STLPORT_PATCHLEVEL` | V.R.P
`_STLPORT_VERSION` | V.R.P
`__SGI_STL_PORT` | V.R.P

##### `BOOST_LIB_STD_IBM`

IBM VACPP Standard C++ library.

Symbol | Version
--- | ---
`__IBMCPP__` | detection